@@ -18,7 +18,7 @@ void QDNSItemModel::setSecurityStatus(QStandardItem *item,
 
 QVariant QDNSItemModel::data(const QModelIndex &index, int role) const
 {
-#if defined(Q_WS_MAEMO_5) || defined(MAEMO_CHANGES)
+#ifdef BROKENBACKGROUND
 #define CHANGEROLE Qt::ForegroundRole
 #else
 #define CHANGEROLE Qt::BackgroundRole
@@ -29,14 +29,18 @@ QVariant QDNSItemModel::data(const QModelIndex &index, int role) const
             return QColor(150,255,150);
         if (m_istrusted == trusted)
             return QColor(255,255,150);
+        if (m_istrusted == bad)
+            return QColor(255,150,150);
         if (m_istrusted == unknown)
-            return QColor(150,255,255);
+            return QColor(255,255,255);
     }
-#if !defined(Q_WS_MAEMO_5) && !defined(MAEMO_CHANGES)
+
+#ifndef BROKENBACKGROUND
+    // we color the background specifically, so the font color must be dark
     if (role == Qt::ForegroundRole) {
         return QColor(0,0,0);
     }
 #endif
-    
+
     return QStandardItemModel::data(index, role);
 }
