@@ -4,6 +4,10 @@
 #include <QtGui/QWidget>
 #include <QtGui/QStandardItemModel>
 
+#if (defined(Q_WS_MAEMO_5) || defined(MAEMO_CHANGES))
+#define BROKENBACKGROUND 1
+#endif
+
 class QDNSItemModel : public QStandardItemModel
 {
     Q_OBJECT
@@ -12,7 +16,7 @@ class QDNSItemModel : public QStandardItemModel
     QDNSItemModel(QObject *parent = 0);
     virtual ~QDNSItemModel();
 
-    enum securityStatus { validated, trusted, unknown };
+    enum securityStatus { validated, trusted, bad, unknown };
 
     void setSecurityStatus(QStandardItem *item, securityStatus istrusted);
     QVariant data(const QModelIndex &index, int role) const;
